# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/ray_client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/ray_client.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!src/ray/protobuf/ray_client.proto\x12\x07ray.rpc\"\xb5\x01\n\x03\x41rg\x12+\n\x05local\x18\x01 \x01(\x0e\x32\x15.ray.rpc.Arg.LocalityR\x05local\x12!\n\x0creference_id\x18\x02 \x01(\x0cR\x0breferenceId\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\x12!\n\x04type\x18\x04 \x01(\x0e\x32\r.ray.rpc.TypeR\x04type\"\'\n\x08Locality\x12\x0c\n\x08INTERNED\x10\x00\x12\r\n\tREFERENCE\x10\x01\"0\n\x0bTaskOptions\x12!\n\x0cjson_options\x18\x01 \x01(\tR\x0bjsonOptions\"\xa2\x04\n\nClientTask\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32\".ray.rpc.ClientTask.RemoteExecTypeR\x04type\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\npayload_id\x18\x03 \x01(\x0cR\tpayloadId\x12 \n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x0c.ray.rpc.ArgR\x04\x61rgs\x12\x37\n\x06kwargs\x18\x05 \x03(\x0b\x32\x1f.ray.rpc.ClientTask.KwargsEntryR\x06kwargs\x12\x1b\n\tclient_id\x18\x06 \x01(\tR\x08\x63lientId\x12.\n\x07options\x18\x07 \x01(\x0b\x32\x14.ray.rpc.TaskOptionsR\x07options\x12?\n\x10\x62\x61seline_options\x18\x08 \x01(\x0b\x32\x14.ray.rpc.TaskOptionsR\x0f\x62\x61selineOptions\x12\x1c\n\tnamespace\x18\t \x01(\tR\tnamespace\x1aG\n\x0bKwargsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ray.rpc.ArgR\x05value:\x02\x38\x01\"Y\n\x0eRemoteExecType\x12\x0c\n\x08\x46UNCTION\x10\x00\x12\t\n\x05\x41\x43TOR\x10\x01\x12\n\n\x06METHOD\x10\x02\x12\x11\n\rSTATIC_METHOD\x10\x03\x12\x0f\n\x0bNAMED_ACTOR\x10\x04\"]\n\x10\x43lientTaskTicket\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x1d\n\nreturn_ids\x18\x02 \x03(\x0cR\treturnIds\x12\x14\n\x05\x65rror\x18\x03 \x01(\x0cR\x05\x65rror\"D\n\nPutRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\"\n\rclient_ref_id\x18\x02 \x01(\x0cR\x0b\x63lientRefId\"I\n\x0bPutResponse\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x14\n\x05valid\x18\x02 \x01(\x08R\x05valid\x12\x14\n\x05\x65rror\x18\x03 \x01(\x0cR\x05\x65rror\"p\n\nGetRequest\x12\x10\n\x03ids\x18\x04 \x03(\x0cR\x03ids\x12\x18\n\x07timeout\x18\x02 \x01(\x02R\x07timeout\x12\"\n\x0c\x61synchronous\x18\x03 \x01(\x08R\x0c\x61synchronous\x12\x12\n\x02id\x18\x01 \x01(\x0c\x42\x02\x18\x01R\x02id\"M\n\x0bGetResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x14\n\x05\x65rror\x18\x03 \x01(\x0cR\x05\x65rror\"\x84\x01\n\x0bWaitRequest\x12\x1d\n\nobject_ids\x18\x01 \x03(\x0cR\tobjectIds\x12\x1f\n\x0bnum_returns\x18\x02 \x01(\x03R\nnumReturns\x12\x18\n\x07timeout\x18\x03 \x01(\x01R\x07timeout\x12\x1b\n\tclient_id\x18\x04 \x01(\tR\x08\x63lientId\"\x80\x01\n\x0cWaitResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12(\n\x10ready_object_ids\x18\x02 \x03(\x0cR\x0ereadyObjectIds\x12\x30\n\x14remaining_object_ids\x18\x03 \x03(\x0cR\x12remainingObjectIds\"\x9a\x01\n\x0f\x43lusterInfoType\"\x86\x01\n\x08TypeEnum\x12\x12\n\x0eIS_INITIALIZED\x10\x00\x12\t\n\x05NODES\x10\x01\x12\x15\n\x11\x43LUSTER_RESOURCES\x10\x02\x12\x17\n\x13\x41VAILABLE_RESOURCES\x10\x03\x12\x13\n\x0fRUNTIME_CONTEXT\x10\x04\x12\x0c\n\x08TIMELINE\x10\x05\x12\x08\n\x04PING\x10\x06\"K\n\x12\x43lusterInfoRequest\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32!.ray.rpc.ClusterInfoType.TypeEnumR\x04type\"\xed\x04\n\x13\x43lusterInfoResponse\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32!.ray.rpc.ClusterInfoType.TypeEnumR\x04type\x12\x14\n\x04json\x18\x02 \x01(\tH\x00R\x04json\x12S\n\x0eresource_table\x18\x03 \x01(\x0b\x32*.ray.rpc.ClusterInfoResponse.ResourceTableH\x00R\rresourceTable\x12V\n\x0fruntime_context\x18\x04 \x01(\x0b\x32+.ray.rpc.ClusterInfoResponse.RuntimeContextH\x00R\x0eruntimeContext\x1a\x96\x01\n\rResourceTable\x12K\n\x05table\x18\x01 \x03(\x0b\x32\x35.ray.rpc.ClusterInfoResponse.ResourceTable.TableEntryR\x05table\x1a\x38\n\nTableEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1a\xb1\x01\n\x0eRuntimeContext\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x1f\n\x0bruntime_env\x18\x04 \x01(\tR\nruntimeEnv\x12\x30\n\x14\x63\x61pture_client_tasks\x18\x05 \x01(\x08R\x12\x63\x61ptureClientTasksB\x0f\n\rresponse_type\"\xf1\x02\n\x10TerminateRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12@\n\x05\x61\x63tor\x18\x02 \x01(\x0b\x32(.ray.rpc.TerminateRequest.ActorTerminateH\x00R\x05\x61\x63tor\x12P\n\x0btask_object\x18\x03 \x01(\x0b\x32-.ray.rpc.TerminateRequest.TaskObjectTerminateH\x00R\ntaskObject\x1a?\n\x0e\x41\x63torTerminate\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x1d\n\nno_restart\x18\x02 \x01(\x08R\tnoRestart\x1aY\n\x13TaskObjectTerminate\x12\x0e\n\x02id\x18\x01 \x01(\x0cR\x02id\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\x12\x1c\n\trecursive\x18\x03 \x01(\x08R\trecursiveB\x10\n\x0eterminate_type\"#\n\x11TerminateResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok\"#\n\x0fKVExistsRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"*\n\x10KVExistsResponse\x12\x16\n\x06\x65xists\x18\x01 \x01(\x08R\x06\x65xists\" \n\x0cKVGetRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"%\n\rKVGetResponse\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"T\n\x0cKVPutRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12\x1c\n\toverwrite\x18\x03 \x01(\x08R\toverwrite\"6\n\rKVPutResponse\x12%\n\x0e\x61lready_exists\x18\x01 \x01(\x08R\ralreadyExists\" \n\x0cKVDelRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"\x0f\n\rKVDelResponse\"\'\n\rKVListRequest\x12\x16\n\x06prefix\x18\x01 \x01(\x0cR\x06prefix\"$\n\x0eKVListResponse\x12\x12\n\x04keys\x18\x01 \x03(\x0cR\x04keys\"\x8a\x01\n\x0bInitRequest\x12\x1d\n\njob_config\x18\x01 \x01(\x0cR\tjobConfig\x12&\n\x0fray_init_kwargs\x18\x02 \x01(\tR\rrayInitKwargs\x12\x34\n\x16reconnect_grace_period\x18\x03 \x01(\x05R\x14reconnectGracePeriod\"0\n\x0cInitResponse\x12\x0e\n\x02ok\x18\x01 \x01(\x08R\x02ok\x12\x10\n\x03msg\x18\x02 \x01(\tR\x03msg\"\x17\n\x15PrepRuntimeEnvRequest\"\x18\n\x16PrepRuntimeEnvResponse\"E\n\x1c\x43lientListNamedActorsRequest\x12%\n\x0e\x61ll_namespaces\x18\x01 \x01(\x08R\rallNamespaces\"@\n\x1d\x43lientListNamedActorsResponse\x12\x1f\n\x0b\x61\x63tors_json\x18\x01 \x01(\tR\nactorsJson\"\"\n\x0eReleaseRequest\x12\x10\n\x03ids\x18\x01 \x03(\x0cR\x03ids\"!\n\x0fReleaseResponse\x12\x0e\n\x02ok\x18\x02 \x03(\x08R\x02ok\"\x17\n\x15\x43onnectionInfoRequest\"\xcb\x01\n\x16\x43onnectionInfoResponse\x12\x1f\n\x0bnum_clients\x18\x01 \x01(\x05R\nnumClients\x12\x1f\n\x0bray_version\x18\x02 \x01(\tR\nrayVersion\x12\x1d\n\nray_commit\x18\x03 \x01(\tR\trayCommit\x12%\n\x0epython_version\x18\x04 \x01(\tR\rpythonVersion\x12)\n\x10protocol_version\x18\x05 \x01(\tR\x0fprotocolVersion\"\x1a\n\x18\x43onnectionCleanupRequest\"\x1b\n\x19\x43onnectionCleanupResponse\"+\n\x12\x41\x63knowledgeRequest\x12\x15\n\x06req_id\x18\x01 \x01(\x05R\x05reqId\"\xc6\x05\n\x0b\x44\x61taRequest\x12\x15\n\x06req_id\x18\x01 \x01(\x05R\x05reqId\x12\'\n\x03get\x18\x02 \x01(\x0b\x32\x13.ray.rpc.GetRequestH\x00R\x03get\x12\'\n\x03put\x18\x03 \x01(\x0b\x32\x13.ray.rpc.PutRequestH\x00R\x03put\x12\x33\n\x07release\x18\x04 \x01(\x0b\x32\x17.ray.rpc.ReleaseRequestH\x00R\x07release\x12I\n\x0f\x63onnection_info\x18\x05 \x01(\x0b\x32\x1e.ray.rpc.ConnectionInfoRequestH\x00R\x0e\x63onnectionInfo\x12*\n\x04init\x18\x06 \x01(\x0b\x32\x14.ray.rpc.InitRequestH\x00R\x04init\x12J\n\x10prep_runtime_env\x18\x07 \x01(\x0b\x32\x1e.ray.rpc.PrepRuntimeEnvRequestH\x00R\x0eprepRuntimeEnv\x12R\n\x12\x63onnection_cleanup\x18\x08 \x01(\x0b\x32!.ray.rpc.ConnectionCleanupRequestH\x00R\x11\x63onnectionCleanup\x12?\n\x0b\x61\x63knowledge\x18\t \x01(\x0b\x32\x1b.ray.rpc.AcknowledgeRequestH\x00R\x0b\x61\x63knowledge\x12)\n\x04task\x18\n \x01(\x0b\x32\x13.ray.rpc.ClientTaskH\x00R\x04task\x12\x39\n\tterminate\x18\x0b \x01(\x0b\x32\x19.ray.rpc.TerminateRequestH\x00R\tterminate\x12S\n\x11list_named_actors\x18\x0c \x01(\x0b\x32%.ray.rpc.ClientListNamedActorsRequestH\x00R\x0flistNamedActorsB\x06\n\x04type\"\xb5\x05\n\x0c\x44\x61taResponse\x12\x15\n\x06req_id\x18\x01 \x01(\x05R\x05reqId\x12(\n\x03get\x18\x02 \x01(\x0b\x32\x14.ray.rpc.GetResponseH\x00R\x03get\x12(\n\x03put\x18\x03 \x01(\x0b\x32\x14.ray.rpc.PutResponseH\x00R\x03put\x12\x34\n\x07release\x18\x04 \x01(\x0b\x32\x18.ray.rpc.ReleaseResponseH\x00R\x07release\x12J\n\x0f\x63onnection_info\x18\x05 \x01(\x0b\x32\x1f.ray.rpc.ConnectionInfoResponseH\x00R\x0e\x63onnectionInfo\x12+\n\x04init\x18\x06 \x01(\x0b\x32\x15.ray.rpc.InitResponseH\x00R\x04init\x12K\n\x10prep_runtime_env\x18\x07 \x01(\x0b\x32\x1f.ray.rpc.PrepRuntimeEnvResponseH\x00R\x0eprepRuntimeEnv\x12S\n\x12\x63onnection_cleanup\x18\x08 \x01(\x0b\x32\".ray.rpc.ConnectionCleanupResponseH\x00R\x11\x63onnectionCleanup\x12<\n\x0btask_ticket\x18\n \x01(\x0b\x32\x19.ray.rpc.ClientTaskTicketH\x00R\ntaskTicket\x12:\n\tterminate\x18\x0b \x01(\x0b\x32\x1a.ray.rpc.TerminateResponseH\x00R\tterminate\x12T\n\x11list_named_actors\x18\x0c \x01(\x0b\x32&.ray.rpc.ClientListNamedActorsResponseH\x00R\x0flistNamedActorsB\x06\n\x04typeJ\x04\x08\t\x10\nR\x0b\x61\x63knowledge\"J\n\x12LogSettingsRequest\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x1a\n\x08loglevel\x18\x02 \x01(\x05R\x08loglevel\"E\n\x07LogData\x12\x10\n\x03msg\x18\x01 \x01(\tR\x03msg\x12\x14\n\x05level\x18\x02 \x01(\x05R\x05level\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name*\x13\n\x04Type\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x32\xad\x07\n\x0cRayletDriver\x12\x35\n\x04Init\x12\x14.ray.rpc.InitRequest\x1a\x15.ray.rpc.InitResponse\"\x00\x12S\n\x0ePrepRuntimeEnv\x12\x1e.ray.rpc.PrepRuntimeEnvRequest\x1a\x1f.ray.rpc.PrepRuntimeEnvResponse\"\x00\x12\x38\n\tGetObject\x12\x13.ray.rpc.GetRequest\x1a\x14.ray.rpc.GetResponse\"\x00\x12\x38\n\tPutObject\x12\x13.ray.rpc.PutRequest\x1a\x14.ray.rpc.PutResponse\"\x00\x12;\n\nWaitObject\x12\x14.ray.rpc.WaitRequest\x1a\x15.ray.rpc.WaitResponse\"\x00\x12<\n\x08Schedule\x12\x13.ray.rpc.ClientTask\x1a\x19.ray.rpc.ClientTaskTicket\"\x00\x12\x44\n\tTerminate\x12\x19.ray.rpc.TerminateRequest\x1a\x1a.ray.rpc.TerminateResponse\"\x00\x12J\n\x0b\x43lusterInfo\x12\x1b.ray.rpc.ClusterInfoRequest\x1a\x1c.ray.rpc.ClusterInfoResponse\"\x00\x12\x38\n\x05KVGet\x12\x15.ray.rpc.KVGetRequest\x1a\x16.ray.rpc.KVGetResponse\"\x00\x12\x38\n\x05KVPut\x12\x15.ray.rpc.KVPutRequest\x1a\x16.ray.rpc.KVPutResponse\"\x00\x12\x38\n\x05KVDel\x12\x15.ray.rpc.KVDelRequest\x1a\x16.ray.rpc.KVDelResponse\"\x00\x12;\n\x06KVList\x12\x16.ray.rpc.KVListRequest\x1a\x17.ray.rpc.KVListResponse\"\x00\x12\x41\n\x08KVExists\x12\x18.ray.rpc.KVExistsRequest\x1a\x19.ray.rpc.KVExistsResponse\"\x00\x12\x62\n\x0fListNamedActors\x12%.ray.rpc.ClientListNamedActorsRequest\x1a&.ray.rpc.ClientListNamedActorsResponse\"\x00\x32S\n\x12RayletDataStreamer\x12=\n\x08\x44\x61tapath\x12\x14.ray.rpc.DataRequest\x1a\x15.ray.rpc.DataResponse\"\x00(\x01\x30\x01\x32U\n\x11RayletLogStreamer\x12@\n\tLogstream\x12\x1b.ray.rpc.LogSettingsRequest\x1a\x10.ray.rpc.LogData\"\x00(\x01\x30\x01\x42\x03\xf8\x01\x01\x62\x06proto3'
)

_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='ray.rpc.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5560,
  serialized_end=5579,
)
_sym_db.RegisterEnumDescriptor(_TYPE)

Type = enum_type_wrapper.EnumTypeWrapper(_TYPE)
DEFAULT = 0


_ARG_LOCALITY = _descriptor.EnumDescriptor(
  name='Locality',
  full_name='ray.rpc.Arg.Locality',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTERNED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=189,
  serialized_end=228,
)
_sym_db.RegisterEnumDescriptor(_ARG_LOCALITY)

_CLIENTTASK_REMOTEEXECTYPE = _descriptor.EnumDescriptor(
  name='RemoteExecType',
  full_name='ray.rpc.ClientTask.RemoteExecType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FUNCTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIC_METHOD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAMED_ACTOR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=738,
  serialized_end=827,
)
_sym_db.RegisterEnumDescriptor(_CLIENTTASK_REMOTEEXECTYPE)

_CLUSTERINFOTYPE_TYPEENUM = _descriptor.EnumDescriptor(
  name='TypeEnum',
  full_name='ray.rpc.ClusterInfoType.TypeEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IS_INITIALIZED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NODES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_RESOURCES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE_RESOURCES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNTIME_CONTEXT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMELINE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1549,
  serialized_end=1683,
)
_sym_db.RegisterEnumDescriptor(_CLUSTERINFOTYPE_TYPEENUM)


_ARG = _descriptor.Descriptor(
  name='Arg',
  full_name='ray.rpc.Arg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local', full_name='ray.rpc.Arg.local', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='local', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_id', full_name='ray.rpc.Arg.reference_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='referenceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.Arg.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.Arg.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ARG_LOCALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=228,
)


_TASKOPTIONS = _descriptor.Descriptor(
  name='TaskOptions',
  full_name='ray.rpc.TaskOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_options', full_name='ray.rpc.TaskOptions.json_options', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=278,
)


_CLIENTTASK_KWARGSENTRY = _descriptor.Descriptor(
  name='KwargsEntry',
  full_name='ray.rpc.ClientTask.KwargsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ClientTask.KwargsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ClientTask.KwargsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=736,
)

_CLIENTTASK = _descriptor.Descriptor(
  name='ClientTask',
  full_name='ray.rpc.ClientTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.ClientTask.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.ClientTask.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_id', full_name='ray.rpc.ClientTask.payload_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='payloadId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='ray.rpc.ClientTask.args', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='args', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kwargs', full_name='ray.rpc.ClientTask.kwargs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kwargs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ray.rpc.ClientTask.client_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='ray.rpc.ClientTask.options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseline_options', full_name='ray.rpc.ClientTask.baseline_options', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='baselineOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ray.rpc.ClientTask.namespace', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTTASK_KWARGSENTRY, ],
  enum_types=[
    _CLIENTTASK_REMOTEEXECTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=827,
)


_CLIENTTASKTICKET = _descriptor.Descriptor(
  name='ClientTaskTicket',
  full_name='ray.rpc.ClientTaskTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='ray.rpc.ClientTaskTicket.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_ids', full_name='ray.rpc.ClientTaskTicket.return_ids', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='returnIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ray.rpc.ClientTaskTicket.error', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=922,
)


_PUTREQUEST = _descriptor.Descriptor(
  name='PutRequest',
  full_name='ray.rpc.PutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.PutRequest.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_ref_id', full_name='ray.rpc.PutRequest.client_ref_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientRefId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=992,
)


_PUTRESPONSE = _descriptor.Descriptor(
  name='PutResponse',
  full_name='ray.rpc.PutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.PutResponse.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid', full_name='ray.rpc.PutResponse.valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ray.rpc.PutResponse.error', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1067,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ray.rpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='ray.rpc.GetRequest.ids', index=0,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ids', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ray.rpc.GetRequest.timeout', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeout', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asynchronous', full_name='ray.rpc.GetRequest.asynchronous', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='asynchronous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.GetRequest.id', index=3,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1181,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ray.rpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='ray.rpc.GetResponse.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.GetResponse.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ray.rpc.GetResponse.error', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1183,
  serialized_end=1260,
)


_WAITREQUEST = _descriptor.Descriptor(
  name='WaitRequest',
  full_name='ray.rpc.WaitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_ids', full_name='ray.rpc.WaitRequest.object_ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_returns', full_name='ray.rpc.WaitRequest.num_returns', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReturns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ray.rpc.WaitRequest.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeout', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ray.rpc.WaitRequest.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1395,
)


_WAITRESPONSE = _descriptor.Descriptor(
  name='WaitResponse',
  full_name='ray.rpc.WaitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='ray.rpc.WaitResponse.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='valid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ready_object_ids', full_name='ray.rpc.WaitResponse.ready_object_ids', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='readyObjectIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remaining_object_ids', full_name='ray.rpc.WaitResponse.remaining_object_ids', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='remainingObjectIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1398,
  serialized_end=1526,
)


_CLUSTERINFOTYPE = _descriptor.Descriptor(
  name='ClusterInfoType',
  full_name='ray.rpc.ClusterInfoType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLUSTERINFOTYPE_TYPEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1683,
)


_CLUSTERINFOREQUEST = _descriptor.Descriptor(
  name='ClusterInfoRequest',
  full_name='ray.rpc.ClusterInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.ClusterInfoRequest.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1685,
  serialized_end=1760,
)


_CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY = _descriptor.Descriptor(
  name='TableEntry',
  full_name='ray.rpc.ClusterInfoResponse.ResourceTable.TableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.ClusterInfoResponse.ResourceTable.TableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.ClusterInfoResponse.ResourceTable.TableEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2187,
)

_CLUSTERINFORESPONSE_RESOURCETABLE = _descriptor.Descriptor(
  name='ResourceTable',
  full_name='ray.rpc.ClusterInfoResponse.ResourceTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='ray.rpc.ClusterInfoResponse.ResourceTable.table', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2037,
  serialized_end=2187,
)

_CLUSTERINFORESPONSE_RUNTIMECONTEXT = _descriptor.Descriptor(
  name='RuntimeContext',
  full_name='ray.rpc.ClusterInfoResponse.RuntimeContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.ClusterInfoResponse.RuntimeContext.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.ClusterInfoResponse.RuntimeContext.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='ray.rpc.ClusterInfoResponse.RuntimeContext.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_env', full_name='ray.rpc.ClusterInfoResponse.RuntimeContext.runtime_env', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runtimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capture_client_tasks', full_name='ray.rpc.ClusterInfoResponse.RuntimeContext.capture_client_tasks', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='captureClientTasks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2190,
  serialized_end=2367,
)

_CLUSTERINFORESPONSE = _descriptor.Descriptor(
  name='ClusterInfoResponse',
  full_name='ray.rpc.ClusterInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.ClusterInfoResponse.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='ray.rpc.ClusterInfoResponse.json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='json', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_table', full_name='ray.rpc.ClusterInfoResponse.resource_table', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_context', full_name='ray.rpc.ClusterInfoResponse.runtime_context', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='runtimeContext', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERINFORESPONSE_RESOURCETABLE, _CLUSTERINFORESPONSE_RUNTIMECONTEXT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response_type', full_name='ray.rpc.ClusterInfoResponse.response_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1763,
  serialized_end=2384,
)


_TERMINATEREQUEST_ACTORTERMINATE = _descriptor.Descriptor(
  name='ActorTerminate',
  full_name='ray.rpc.TerminateRequest.ActorTerminate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.TerminateRequest.ActorTerminate.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_restart', full_name='ray.rpc.TerminateRequest.ActorTerminate.no_restart', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='noRestart', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2584,
  serialized_end=2647,
)

_TERMINATEREQUEST_TASKOBJECTTERMINATE = _descriptor.Descriptor(
  name='TaskObjectTerminate',
  full_name='ray.rpc.TerminateRequest.TaskObjectTerminate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ray.rpc.TerminateRequest.TaskObjectTerminate.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='ray.rpc.TerminateRequest.TaskObjectTerminate.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='force', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='ray.rpc.TerminateRequest.TaskObjectTerminate.recursive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='recursive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=2738,
)

_TERMINATEREQUEST = _descriptor.Descriptor(
  name='TerminateRequest',
  full_name='ray.rpc.TerminateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ray.rpc.TerminateRequest.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor', full_name='ray.rpc.TerminateRequest.actor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_object', full_name='ray.rpc.TerminateRequest.task_object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskObject', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TERMINATEREQUEST_ACTORTERMINATE, _TERMINATEREQUEST_TASKOBJECTTERMINATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='terminate_type', full_name='ray.rpc.TerminateRequest.terminate_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2387,
  serialized_end=2756,
)


_TERMINATERESPONSE = _descriptor.Descriptor(
  name='TerminateResponse',
  full_name='ray.rpc.TerminateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='ray.rpc.TerminateResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ok', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2758,
  serialized_end=2793,
)


_KVEXISTSREQUEST = _descriptor.Descriptor(
  name='KVExistsRequest',
  full_name='ray.rpc.KVExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.KVExistsRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2830,
)


_KVEXISTSRESPONSE = _descriptor.Descriptor(
  name='KVExistsResponse',
  full_name='ray.rpc.KVExistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='ray.rpc.KVExistsResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exists', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2832,
  serialized_end=2874,
)


_KVGETREQUEST = _descriptor.Descriptor(
  name='KVGetRequest',
  full_name='ray.rpc.KVGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.KVGetRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2908,
)


_KVGETRESPONSE = _descriptor.Descriptor(
  name='KVGetResponse',
  full_name='ray.rpc.KVGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.KVGetResponse.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2910,
  serialized_end=2947,
)


_KVPUTREQUEST = _descriptor.Descriptor(
  name='KVPutRequest',
  full_name='ray.rpc.KVPutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.KVPutRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.KVPutRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='ray.rpc.KVPutRequest.overwrite', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overwrite', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=3033,
)


_KVPUTRESPONSE = _descriptor.Descriptor(
  name='KVPutResponse',
  full_name='ray.rpc.KVPutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='already_exists', full_name='ray.rpc.KVPutResponse.already_exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alreadyExists', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3089,
)


_KVDELREQUEST = _descriptor.Descriptor(
  name='KVDelRequest',
  full_name='ray.rpc.KVDelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.KVDelRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3091,
  serialized_end=3123,
)


_KVDELRESPONSE = _descriptor.Descriptor(
  name='KVDelResponse',
  full_name='ray.rpc.KVDelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3125,
  serialized_end=3140,
)


_KVLISTREQUEST = _descriptor.Descriptor(
  name='KVListRequest',
  full_name='ray.rpc.KVListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='ray.rpc.KVListRequest.prefix', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='prefix', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3142,
  serialized_end=3181,
)


_KVLISTRESPONSE = _descriptor.Descriptor(
  name='KVListResponse',
  full_name='ray.rpc.KVListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='ray.rpc.KVListResponse.keys', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='keys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3183,
  serialized_end=3219,
)


_INITREQUEST = _descriptor.Descriptor(
  name='InitRequest',
  full_name='ray.rpc.InitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_config', full_name='ray.rpc.InitRequest.job_config', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_init_kwargs', full_name='ray.rpc.InitRequest.ray_init_kwargs', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayInitKwargs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reconnect_grace_period', full_name='ray.rpc.InitRequest.reconnect_grace_period', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reconnectGracePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3222,
  serialized_end=3360,
)


_INITRESPONSE = _descriptor.Descriptor(
  name='InitResponse',
  full_name='ray.rpc.InitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='ray.rpc.InitResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ok', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='ray.rpc.InitResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='msg', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3362,
  serialized_end=3410,
)


_PREPRUNTIMEENVREQUEST = _descriptor.Descriptor(
  name='PrepRuntimeEnvRequest',
  full_name='ray.rpc.PrepRuntimeEnvRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3412,
  serialized_end=3435,
)


_PREPRUNTIMEENVRESPONSE = _descriptor.Descriptor(
  name='PrepRuntimeEnvResponse',
  full_name='ray.rpc.PrepRuntimeEnvResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3437,
  serialized_end=3461,
)


_CLIENTLISTNAMEDACTORSREQUEST = _descriptor.Descriptor(
  name='ClientListNamedActorsRequest',
  full_name='ray.rpc.ClientListNamedActorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_namespaces', full_name='ray.rpc.ClientListNamedActorsRequest.all_namespaces', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='allNamespaces', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3532,
)


_CLIENTLISTNAMEDACTORSRESPONSE = _descriptor.Descriptor(
  name='ClientListNamedActorsResponse',
  full_name='ray.rpc.ClientListNamedActorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actors_json', full_name='ray.rpc.ClientListNamedActorsResponse.actors_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorsJson', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3534,
  serialized_end=3598,
)


_RELEASEREQUEST = _descriptor.Descriptor(
  name='ReleaseRequest',
  full_name='ray.rpc.ReleaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='ray.rpc.ReleaseRequest.ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ids', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3600,
  serialized_end=3634,
)


_RELEASERESPONSE = _descriptor.Descriptor(
  name='ReleaseResponse',
  full_name='ray.rpc.ReleaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='ray.rpc.ReleaseResponse.ok', index=0,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ok', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3636,
  serialized_end=3669,
)


_CONNECTIONINFOREQUEST = _descriptor.Descriptor(
  name='ConnectionInfoRequest',
  full_name='ray.rpc.ConnectionInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3671,
  serialized_end=3694,
)


_CONNECTIONINFORESPONSE = _descriptor.Descriptor(
  name='ConnectionInfoResponse',
  full_name='ray.rpc.ConnectionInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_clients', full_name='ray.rpc.ConnectionInfoResponse.num_clients', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numClients', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_version', full_name='ray.rpc.ConnectionInfoResponse.ray_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_commit', full_name='ray.rpc.ConnectionInfoResponse.ray_commit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayCommit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='python_version', full_name='ray.rpc.ConnectionInfoResponse.python_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pythonVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='ray.rpc.ConnectionInfoResponse.protocol_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='protocolVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3697,
  serialized_end=3900,
)


_CONNECTIONCLEANUPREQUEST = _descriptor.Descriptor(
  name='ConnectionCleanupRequest',
  full_name='ray.rpc.ConnectionCleanupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3902,
  serialized_end=3928,
)


_CONNECTIONCLEANUPRESPONSE = _descriptor.Descriptor(
  name='ConnectionCleanupResponse',
  full_name='ray.rpc.ConnectionCleanupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3930,
  serialized_end=3957,
)


_ACKNOWLEDGEREQUEST = _descriptor.Descriptor(
  name='AcknowledgeRequest',
  full_name='ray.rpc.AcknowledgeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='ray.rpc.AcknowledgeRequest.req_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3959,
  serialized_end=4002,
)


_DATAREQUEST = _descriptor.Descriptor(
  name='DataRequest',
  full_name='ray.rpc.DataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='ray.rpc.DataRequest.req_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get', full_name='ray.rpc.DataRequest.get', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='get', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='put', full_name='ray.rpc.DataRequest.put', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='put', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release', full_name='ray.rpc.DataRequest.release', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='release', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_info', full_name='ray.rpc.DataRequest.connection_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='connectionInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init', full_name='ray.rpc.DataRequest.init', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='init', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prep_runtime_env', full_name='ray.rpc.DataRequest.prep_runtime_env', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='prepRuntimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_cleanup', full_name='ray.rpc.DataRequest.connection_cleanup', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='connectionCleanup', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acknowledge', full_name='ray.rpc.DataRequest.acknowledge', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='acknowledge', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task', full_name='ray.rpc.DataRequest.task', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='task', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminate', full_name='ray.rpc.DataRequest.terminate', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='terminate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_named_actors', full_name='ray.rpc.DataRequest.list_named_actors', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='listNamedActors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ray.rpc.DataRequest.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4005,
  serialized_end=4715,
)


_DATARESPONSE = _descriptor.Descriptor(
  name='DataResponse',
  full_name='ray.rpc.DataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='ray.rpc.DataResponse.req_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get', full_name='ray.rpc.DataResponse.get', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='get', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='put', full_name='ray.rpc.DataResponse.put', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='put', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release', full_name='ray.rpc.DataResponse.release', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='release', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_info', full_name='ray.rpc.DataResponse.connection_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='connectionInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init', full_name='ray.rpc.DataResponse.init', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='init', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prep_runtime_env', full_name='ray.rpc.DataResponse.prep_runtime_env', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='prepRuntimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_cleanup', full_name='ray.rpc.DataResponse.connection_cleanup', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='connectionCleanup', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_ticket', full_name='ray.rpc.DataResponse.task_ticket', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskTicket', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminate', full_name='ray.rpc.DataResponse.terminate', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='terminate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_named_actors', full_name='ray.rpc.DataResponse.list_named_actors', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='listNamedActors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ray.rpc.DataResponse.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4718,
  serialized_end=5411,
)


_LOGSETTINGSREQUEST = _descriptor.Descriptor(
  name='LogSettingsRequest',
  full_name='ray.rpc.LogSettingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ray.rpc.LogSettingsRequest.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loglevel', full_name='ray.rpc.LogSettingsRequest.loglevel', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='loglevel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5413,
  serialized_end=5487,
)


_LOGDATA = _descriptor.Descriptor(
  name='LogData',
  full_name='ray.rpc.LogData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='ray.rpc.LogData.msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='msg', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='ray.rpc.LogData.level', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='level', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.LogData.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5489,
  serialized_end=5558,
)

_ARG.fields_by_name['local'].enum_type = _ARG_LOCALITY
_ARG.fields_by_name['type'].enum_type = _TYPE
_ARG_LOCALITY.containing_type = _ARG
_CLIENTTASK_KWARGSENTRY.fields_by_name['value'].message_type = _ARG
_CLIENTTASK_KWARGSENTRY.containing_type = _CLIENTTASK
_CLIENTTASK.fields_by_name['type'].enum_type = _CLIENTTASK_REMOTEEXECTYPE
_CLIENTTASK.fields_by_name['args'].message_type = _ARG
_CLIENTTASK.fields_by_name['kwargs'].message_type = _CLIENTTASK_KWARGSENTRY
_CLIENTTASK.fields_by_name['options'].message_type = _TASKOPTIONS
_CLIENTTASK.fields_by_name['baseline_options'].message_type = _TASKOPTIONS
_CLIENTTASK_REMOTEEXECTYPE.containing_type = _CLIENTTASK
_CLUSTERINFOTYPE_TYPEENUM.containing_type = _CLUSTERINFOTYPE
_CLUSTERINFOREQUEST.fields_by_name['type'].enum_type = _CLUSTERINFOTYPE_TYPEENUM
_CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY.containing_type = _CLUSTERINFORESPONSE_RESOURCETABLE
_CLUSTERINFORESPONSE_RESOURCETABLE.fields_by_name['table'].message_type = _CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY
_CLUSTERINFORESPONSE_RESOURCETABLE.containing_type = _CLUSTERINFORESPONSE
_CLUSTERINFORESPONSE_RUNTIMECONTEXT.containing_type = _CLUSTERINFORESPONSE
_CLUSTERINFORESPONSE.fields_by_name['type'].enum_type = _CLUSTERINFOTYPE_TYPEENUM
_CLUSTERINFORESPONSE.fields_by_name['resource_table'].message_type = _CLUSTERINFORESPONSE_RESOURCETABLE
_CLUSTERINFORESPONSE.fields_by_name['runtime_context'].message_type = _CLUSTERINFORESPONSE_RUNTIMECONTEXT
_CLUSTERINFORESPONSE.oneofs_by_name['response_type'].fields.append(
  _CLUSTERINFORESPONSE.fields_by_name['json'])
_CLUSTERINFORESPONSE.fields_by_name['json'].containing_oneof = _CLUSTERINFORESPONSE.oneofs_by_name['response_type']
_CLUSTERINFORESPONSE.oneofs_by_name['response_type'].fields.append(
  _CLUSTERINFORESPONSE.fields_by_name['resource_table'])
_CLUSTERINFORESPONSE.fields_by_name['resource_table'].containing_oneof = _CLUSTERINFORESPONSE.oneofs_by_name['response_type']
_CLUSTERINFORESPONSE.oneofs_by_name['response_type'].fields.append(
  _CLUSTERINFORESPONSE.fields_by_name['runtime_context'])
_CLUSTERINFORESPONSE.fields_by_name['runtime_context'].containing_oneof = _CLUSTERINFORESPONSE.oneofs_by_name['response_type']
_TERMINATEREQUEST_ACTORTERMINATE.containing_type = _TERMINATEREQUEST
_TERMINATEREQUEST_TASKOBJECTTERMINATE.containing_type = _TERMINATEREQUEST
_TERMINATEREQUEST.fields_by_name['actor'].message_type = _TERMINATEREQUEST_ACTORTERMINATE
_TERMINATEREQUEST.fields_by_name['task_object'].message_type = _TERMINATEREQUEST_TASKOBJECTTERMINATE
_TERMINATEREQUEST.oneofs_by_name['terminate_type'].fields.append(
  _TERMINATEREQUEST.fields_by_name['actor'])
_TERMINATEREQUEST.fields_by_name['actor'].containing_oneof = _TERMINATEREQUEST.oneofs_by_name['terminate_type']
_TERMINATEREQUEST.oneofs_by_name['terminate_type'].fields.append(
  _TERMINATEREQUEST.fields_by_name['task_object'])
_TERMINATEREQUEST.fields_by_name['task_object'].containing_oneof = _TERMINATEREQUEST.oneofs_by_name['terminate_type']
_DATAREQUEST.fields_by_name['get'].message_type = _GETREQUEST
_DATAREQUEST.fields_by_name['put'].message_type = _PUTREQUEST
_DATAREQUEST.fields_by_name['release'].message_type = _RELEASEREQUEST
_DATAREQUEST.fields_by_name['connection_info'].message_type = _CONNECTIONINFOREQUEST
_DATAREQUEST.fields_by_name['init'].message_type = _INITREQUEST
_DATAREQUEST.fields_by_name['prep_runtime_env'].message_type = _PREPRUNTIMEENVREQUEST
_DATAREQUEST.fields_by_name['connection_cleanup'].message_type = _CONNECTIONCLEANUPREQUEST
_DATAREQUEST.fields_by_name['acknowledge'].message_type = _ACKNOWLEDGEREQUEST
_DATAREQUEST.fields_by_name['task'].message_type = _CLIENTTASK
_DATAREQUEST.fields_by_name['terminate'].message_type = _TERMINATEREQUEST
_DATAREQUEST.fields_by_name['list_named_actors'].message_type = _CLIENTLISTNAMEDACTORSREQUEST
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['get'])
_DATAREQUEST.fields_by_name['get'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['put'])
_DATAREQUEST.fields_by_name['put'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['release'])
_DATAREQUEST.fields_by_name['release'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['connection_info'])
_DATAREQUEST.fields_by_name['connection_info'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['init'])
_DATAREQUEST.fields_by_name['init'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['prep_runtime_env'])
_DATAREQUEST.fields_by_name['prep_runtime_env'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['connection_cleanup'])
_DATAREQUEST.fields_by_name['connection_cleanup'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['acknowledge'])
_DATAREQUEST.fields_by_name['acknowledge'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['task'])
_DATAREQUEST.fields_by_name['task'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['terminate'])
_DATAREQUEST.fields_by_name['terminate'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATAREQUEST.oneofs_by_name['type'].fields.append(
  _DATAREQUEST.fields_by_name['list_named_actors'])
_DATAREQUEST.fields_by_name['list_named_actors'].containing_oneof = _DATAREQUEST.oneofs_by_name['type']
_DATARESPONSE.fields_by_name['get'].message_type = _GETRESPONSE
_DATARESPONSE.fields_by_name['put'].message_type = _PUTRESPONSE
_DATARESPONSE.fields_by_name['release'].message_type = _RELEASERESPONSE
_DATARESPONSE.fields_by_name['connection_info'].message_type = _CONNECTIONINFORESPONSE
_DATARESPONSE.fields_by_name['init'].message_type = _INITRESPONSE
_DATARESPONSE.fields_by_name['prep_runtime_env'].message_type = _PREPRUNTIMEENVRESPONSE
_DATARESPONSE.fields_by_name['connection_cleanup'].message_type = _CONNECTIONCLEANUPRESPONSE
_DATARESPONSE.fields_by_name['task_ticket'].message_type = _CLIENTTASKTICKET
_DATARESPONSE.fields_by_name['terminate'].message_type = _TERMINATERESPONSE
_DATARESPONSE.fields_by_name['list_named_actors'].message_type = _CLIENTLISTNAMEDACTORSRESPONSE
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['get'])
_DATARESPONSE.fields_by_name['get'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['put'])
_DATARESPONSE.fields_by_name['put'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['release'])
_DATARESPONSE.fields_by_name['release'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['connection_info'])
_DATARESPONSE.fields_by_name['connection_info'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['init'])
_DATARESPONSE.fields_by_name['init'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['prep_runtime_env'])
_DATARESPONSE.fields_by_name['prep_runtime_env'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['connection_cleanup'])
_DATARESPONSE.fields_by_name['connection_cleanup'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['task_ticket'])
_DATARESPONSE.fields_by_name['task_ticket'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['terminate'])
_DATARESPONSE.fields_by_name['terminate'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
_DATARESPONSE.oneofs_by_name['type'].fields.append(
  _DATARESPONSE.fields_by_name['list_named_actors'])
_DATARESPONSE.fields_by_name['list_named_actors'].containing_oneof = _DATARESPONSE.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['Arg'] = _ARG
DESCRIPTOR.message_types_by_name['TaskOptions'] = _TASKOPTIONS
DESCRIPTOR.message_types_by_name['ClientTask'] = _CLIENTTASK
DESCRIPTOR.message_types_by_name['ClientTaskTicket'] = _CLIENTTASKTICKET
DESCRIPTOR.message_types_by_name['PutRequest'] = _PUTREQUEST
DESCRIPTOR.message_types_by_name['PutResponse'] = _PUTRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['WaitRequest'] = _WAITREQUEST
DESCRIPTOR.message_types_by_name['WaitResponse'] = _WAITRESPONSE
DESCRIPTOR.message_types_by_name['ClusterInfoType'] = _CLUSTERINFOTYPE
DESCRIPTOR.message_types_by_name['ClusterInfoRequest'] = _CLUSTERINFOREQUEST
DESCRIPTOR.message_types_by_name['ClusterInfoResponse'] = _CLUSTERINFORESPONSE
DESCRIPTOR.message_types_by_name['TerminateRequest'] = _TERMINATEREQUEST
DESCRIPTOR.message_types_by_name['TerminateResponse'] = _TERMINATERESPONSE
DESCRIPTOR.message_types_by_name['KVExistsRequest'] = _KVEXISTSREQUEST
DESCRIPTOR.message_types_by_name['KVExistsResponse'] = _KVEXISTSRESPONSE
DESCRIPTOR.message_types_by_name['KVGetRequest'] = _KVGETREQUEST
DESCRIPTOR.message_types_by_name['KVGetResponse'] = _KVGETRESPONSE
DESCRIPTOR.message_types_by_name['KVPutRequest'] = _KVPUTREQUEST
DESCRIPTOR.message_types_by_name['KVPutResponse'] = _KVPUTRESPONSE
DESCRIPTOR.message_types_by_name['KVDelRequest'] = _KVDELREQUEST
DESCRIPTOR.message_types_by_name['KVDelResponse'] = _KVDELRESPONSE
DESCRIPTOR.message_types_by_name['KVListRequest'] = _KVLISTREQUEST
DESCRIPTOR.message_types_by_name['KVListResponse'] = _KVLISTRESPONSE
DESCRIPTOR.message_types_by_name['InitRequest'] = _INITREQUEST
DESCRIPTOR.message_types_by_name['InitResponse'] = _INITRESPONSE
DESCRIPTOR.message_types_by_name['PrepRuntimeEnvRequest'] = _PREPRUNTIMEENVREQUEST
DESCRIPTOR.message_types_by_name['PrepRuntimeEnvResponse'] = _PREPRUNTIMEENVRESPONSE
DESCRIPTOR.message_types_by_name['ClientListNamedActorsRequest'] = _CLIENTLISTNAMEDACTORSREQUEST
DESCRIPTOR.message_types_by_name['ClientListNamedActorsResponse'] = _CLIENTLISTNAMEDACTORSRESPONSE
DESCRIPTOR.message_types_by_name['ReleaseRequest'] = _RELEASEREQUEST
DESCRIPTOR.message_types_by_name['ReleaseResponse'] = _RELEASERESPONSE
DESCRIPTOR.message_types_by_name['ConnectionInfoRequest'] = _CONNECTIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ConnectionInfoResponse'] = _CONNECTIONINFORESPONSE
DESCRIPTOR.message_types_by_name['ConnectionCleanupRequest'] = _CONNECTIONCLEANUPREQUEST
DESCRIPTOR.message_types_by_name['ConnectionCleanupResponse'] = _CONNECTIONCLEANUPRESPONSE
DESCRIPTOR.message_types_by_name['AcknowledgeRequest'] = _ACKNOWLEDGEREQUEST
DESCRIPTOR.message_types_by_name['DataRequest'] = _DATAREQUEST
DESCRIPTOR.message_types_by_name['DataResponse'] = _DATARESPONSE
DESCRIPTOR.message_types_by_name['LogSettingsRequest'] = _LOGSETTINGSREQUEST
DESCRIPTOR.message_types_by_name['LogData'] = _LOGDATA
DESCRIPTOR.enum_types_by_name['Type'] = _TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Arg = _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {
  'DESCRIPTOR' : _ARG,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.Arg)
  })
_sym_db.RegisterMessage(Arg)

TaskOptions = _reflection.GeneratedProtocolMessageType('TaskOptions', (_message.Message,), {
  'DESCRIPTOR' : _TASKOPTIONS,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskOptions)
  })
_sym_db.RegisterMessage(TaskOptions)

ClientTask = _reflection.GeneratedProtocolMessageType('ClientTask', (_message.Message,), {

  'KwargsEntry' : _reflection.GeneratedProtocolMessageType('KwargsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLIENTTASK_KWARGSENTRY,
    '__module__' : 'src.ray.protobuf.ray_client_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ClientTask.KwargsEntry)
    })
  ,
  'DESCRIPTOR' : _CLIENTTASK,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClientTask)
  })
_sym_db.RegisterMessage(ClientTask)
_sym_db.RegisterMessage(ClientTask.KwargsEntry)

ClientTaskTicket = _reflection.GeneratedProtocolMessageType('ClientTaskTicket', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTTASKTICKET,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClientTaskTicket)
  })
_sym_db.RegisterMessage(ClientTaskTicket)

PutRequest = _reflection.GeneratedProtocolMessageType('PutRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PutRequest)
  })
_sym_db.RegisterMessage(PutRequest)

PutResponse = _reflection.GeneratedProtocolMessageType('PutResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUTRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PutResponse)
  })
_sym_db.RegisterMessage(PutResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)

WaitRequest = _reflection.GeneratedProtocolMessageType('WaitRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitRequest)
  })
_sym_db.RegisterMessage(WaitRequest)

WaitResponse = _reflection.GeneratedProtocolMessageType('WaitResponse', (_message.Message,), {
  'DESCRIPTOR' : _WAITRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitResponse)
  })
_sym_db.RegisterMessage(WaitResponse)

ClusterInfoType = _reflection.GeneratedProtocolMessageType('ClusterInfoType', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERINFOTYPE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoType)
  })
_sym_db.RegisterMessage(ClusterInfoType)

ClusterInfoRequest = _reflection.GeneratedProtocolMessageType('ClusterInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoRequest)
  })
_sym_db.RegisterMessage(ClusterInfoRequest)

ClusterInfoResponse = _reflection.GeneratedProtocolMessageType('ClusterInfoResponse', (_message.Message,), {

  'ResourceTable' : _reflection.GeneratedProtocolMessageType('ResourceTable', (_message.Message,), {

    'TableEntry' : _reflection.GeneratedProtocolMessageType('TableEntry', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY,
      '__module__' : 'src.ray.protobuf.ray_client_pb2'
      # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoResponse.ResourceTable.TableEntry)
      })
    ,
    'DESCRIPTOR' : _CLUSTERINFORESPONSE_RESOURCETABLE,
    '__module__' : 'src.ray.protobuf.ray_client_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoResponse.ResourceTable)
    })
  ,

  'RuntimeContext' : _reflection.GeneratedProtocolMessageType('RuntimeContext', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERINFORESPONSE_RUNTIMECONTEXT,
    '__module__' : 'src.ray.protobuf.ray_client_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoResponse.RuntimeContext)
    })
  ,
  'DESCRIPTOR' : _CLUSTERINFORESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClusterInfoResponse)
  })
_sym_db.RegisterMessage(ClusterInfoResponse)
_sym_db.RegisterMessage(ClusterInfoResponse.ResourceTable)
_sym_db.RegisterMessage(ClusterInfoResponse.ResourceTable.TableEntry)
_sym_db.RegisterMessage(ClusterInfoResponse.RuntimeContext)

TerminateRequest = _reflection.GeneratedProtocolMessageType('TerminateRequest', (_message.Message,), {

  'ActorTerminate' : _reflection.GeneratedProtocolMessageType('ActorTerminate', (_message.Message,), {
    'DESCRIPTOR' : _TERMINATEREQUEST_ACTORTERMINATE,
    '__module__' : 'src.ray.protobuf.ray_client_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.TerminateRequest.ActorTerminate)
    })
  ,

  'TaskObjectTerminate' : _reflection.GeneratedProtocolMessageType('TaskObjectTerminate', (_message.Message,), {
    'DESCRIPTOR' : _TERMINATEREQUEST_TASKOBJECTTERMINATE,
    '__module__' : 'src.ray.protobuf.ray_client_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.TerminateRequest.TaskObjectTerminate)
    })
  ,
  'DESCRIPTOR' : _TERMINATEREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TerminateRequest)
  })
_sym_db.RegisterMessage(TerminateRequest)
_sym_db.RegisterMessage(TerminateRequest.ActorTerminate)
_sym_db.RegisterMessage(TerminateRequest.TaskObjectTerminate)

TerminateResponse = _reflection.GeneratedProtocolMessageType('TerminateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATERESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TerminateResponse)
  })
_sym_db.RegisterMessage(TerminateResponse)

KVExistsRequest = _reflection.GeneratedProtocolMessageType('KVExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _KVEXISTSREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVExistsRequest)
  })
_sym_db.RegisterMessage(KVExistsRequest)

KVExistsResponse = _reflection.GeneratedProtocolMessageType('KVExistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _KVEXISTSRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVExistsResponse)
  })
_sym_db.RegisterMessage(KVExistsResponse)

KVGetRequest = _reflection.GeneratedProtocolMessageType('KVGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _KVGETREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVGetRequest)
  })
_sym_db.RegisterMessage(KVGetRequest)

KVGetResponse = _reflection.GeneratedProtocolMessageType('KVGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _KVGETRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVGetResponse)
  })
_sym_db.RegisterMessage(KVGetResponse)

KVPutRequest = _reflection.GeneratedProtocolMessageType('KVPutRequest', (_message.Message,), {
  'DESCRIPTOR' : _KVPUTREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVPutRequest)
  })
_sym_db.RegisterMessage(KVPutRequest)

KVPutResponse = _reflection.GeneratedProtocolMessageType('KVPutResponse', (_message.Message,), {
  'DESCRIPTOR' : _KVPUTRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVPutResponse)
  })
_sym_db.RegisterMessage(KVPutResponse)

KVDelRequest = _reflection.GeneratedProtocolMessageType('KVDelRequest', (_message.Message,), {
  'DESCRIPTOR' : _KVDELREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVDelRequest)
  })
_sym_db.RegisterMessage(KVDelRequest)

KVDelResponse = _reflection.GeneratedProtocolMessageType('KVDelResponse', (_message.Message,), {
  'DESCRIPTOR' : _KVDELRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVDelResponse)
  })
_sym_db.RegisterMessage(KVDelResponse)

KVListRequest = _reflection.GeneratedProtocolMessageType('KVListRequest', (_message.Message,), {
  'DESCRIPTOR' : _KVLISTREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVListRequest)
  })
_sym_db.RegisterMessage(KVListRequest)

KVListResponse = _reflection.GeneratedProtocolMessageType('KVListResponse', (_message.Message,), {
  'DESCRIPTOR' : _KVLISTRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KVListResponse)
  })
_sym_db.RegisterMessage(KVListResponse)

InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

InitResponse = _reflection.GeneratedProtocolMessageType('InitResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InitResponse)
  })
_sym_db.RegisterMessage(InitResponse)

PrepRuntimeEnvRequest = _reflection.GeneratedProtocolMessageType('PrepRuntimeEnvRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPRUNTIMEENVREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PrepRuntimeEnvRequest)
  })
_sym_db.RegisterMessage(PrepRuntimeEnvRequest)

PrepRuntimeEnvResponse = _reflection.GeneratedProtocolMessageType('PrepRuntimeEnvResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPRUNTIMEENVRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PrepRuntimeEnvResponse)
  })
_sym_db.RegisterMessage(PrepRuntimeEnvResponse)

ClientListNamedActorsRequest = _reflection.GeneratedProtocolMessageType('ClientListNamedActorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTLISTNAMEDACTORSREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClientListNamedActorsRequest)
  })
_sym_db.RegisterMessage(ClientListNamedActorsRequest)

ClientListNamedActorsResponse = _reflection.GeneratedProtocolMessageType('ClientListNamedActorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTLISTNAMEDACTORSRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ClientListNamedActorsResponse)
  })
_sym_db.RegisterMessage(ClientListNamedActorsResponse)

ReleaseRequest = _reflection.GeneratedProtocolMessageType('ReleaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReleaseRequest)
  })
_sym_db.RegisterMessage(ReleaseRequest)

ReleaseResponse = _reflection.GeneratedProtocolMessageType('ReleaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _RELEASERESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReleaseResponse)
  })
_sym_db.RegisterMessage(ReleaseResponse)

ConnectionInfoRequest = _reflection.GeneratedProtocolMessageType('ConnectionInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONINFOREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ConnectionInfoRequest)
  })
_sym_db.RegisterMessage(ConnectionInfoRequest)

ConnectionInfoResponse = _reflection.GeneratedProtocolMessageType('ConnectionInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONINFORESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ConnectionInfoResponse)
  })
_sym_db.RegisterMessage(ConnectionInfoResponse)

ConnectionCleanupRequest = _reflection.GeneratedProtocolMessageType('ConnectionCleanupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONCLEANUPREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ConnectionCleanupRequest)
  })
_sym_db.RegisterMessage(ConnectionCleanupRequest)

ConnectionCleanupResponse = _reflection.GeneratedProtocolMessageType('ConnectionCleanupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTIONCLEANUPRESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ConnectionCleanupResponse)
  })
_sym_db.RegisterMessage(ConnectionCleanupResponse)

AcknowledgeRequest = _reflection.GeneratedProtocolMessageType('AcknowledgeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACKNOWLEDGEREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AcknowledgeRequest)
  })
_sym_db.RegisterMessage(AcknowledgeRequest)

DataRequest = _reflection.GeneratedProtocolMessageType('DataRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATAREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DataRequest)
  })
_sym_db.RegisterMessage(DataRequest)

DataResponse = _reflection.GeneratedProtocolMessageType('DataResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATARESPONSE,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DataResponse)
  })
_sym_db.RegisterMessage(DataResponse)

LogSettingsRequest = _reflection.GeneratedProtocolMessageType('LogSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGSETTINGSREQUEST,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.LogSettingsRequest)
  })
_sym_db.RegisterMessage(LogSettingsRequest)

LogData = _reflection.GeneratedProtocolMessageType('LogData', (_message.Message,), {
  'DESCRIPTOR' : _LOGDATA,
  '__module__' : 'src.ray.protobuf.ray_client_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.LogData)
  })
_sym_db.RegisterMessage(LogData)


DESCRIPTOR._options = None
_CLIENTTASK_KWARGSENTRY._options = None
_GETREQUEST.fields_by_name['id']._options = None
_CLUSTERINFORESPONSE_RESOURCETABLE_TABLEENTRY._options = None

_RAYLETDRIVER = _descriptor.ServiceDescriptor(
  name='RayletDriver',
  full_name='ray.rpc.RayletDriver',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5582,
  serialized_end=6523,
  methods=[
  _descriptor.MethodDescriptor(
    name='Init',
    full_name='ray.rpc.RayletDriver.Init',
    index=0,
    containing_service=None,
    input_type=_INITREQUEST,
    output_type=_INITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PrepRuntimeEnv',
    full_name='ray.rpc.RayletDriver.PrepRuntimeEnv',
    index=1,
    containing_service=None,
    input_type=_PREPRUNTIMEENVREQUEST,
    output_type=_PREPRUNTIMEENVRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetObject',
    full_name='ray.rpc.RayletDriver.GetObject',
    index=2,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PutObject',
    full_name='ray.rpc.RayletDriver.PutObject',
    index=3,
    containing_service=None,
    input_type=_PUTREQUEST,
    output_type=_PUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitObject',
    full_name='ray.rpc.RayletDriver.WaitObject',
    index=4,
    containing_service=None,
    input_type=_WAITREQUEST,
    output_type=_WAITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Schedule',
    full_name='ray.rpc.RayletDriver.Schedule',
    index=5,
    containing_service=None,
    input_type=_CLIENTTASK,
    output_type=_CLIENTTASKTICKET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Terminate',
    full_name='ray.rpc.RayletDriver.Terminate',
    index=6,
    containing_service=None,
    input_type=_TERMINATEREQUEST,
    output_type=_TERMINATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClusterInfo',
    full_name='ray.rpc.RayletDriver.ClusterInfo',
    index=7,
    containing_service=None,
    input_type=_CLUSTERINFOREQUEST,
    output_type=_CLUSTERINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KVGet',
    full_name='ray.rpc.RayletDriver.KVGet',
    index=8,
    containing_service=None,
    input_type=_KVGETREQUEST,
    output_type=_KVGETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KVPut',
    full_name='ray.rpc.RayletDriver.KVPut',
    index=9,
    containing_service=None,
    input_type=_KVPUTREQUEST,
    output_type=_KVPUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KVDel',
    full_name='ray.rpc.RayletDriver.KVDel',
    index=10,
    containing_service=None,
    input_type=_KVDELREQUEST,
    output_type=_KVDELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KVList',
    full_name='ray.rpc.RayletDriver.KVList',
    index=11,
    containing_service=None,
    input_type=_KVLISTREQUEST,
    output_type=_KVLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KVExists',
    full_name='ray.rpc.RayletDriver.KVExists',
    index=12,
    containing_service=None,
    input_type=_KVEXISTSREQUEST,
    output_type=_KVEXISTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNamedActors',
    full_name='ray.rpc.RayletDriver.ListNamedActors',
    index=13,
    containing_service=None,
    input_type=_CLIENTLISTNAMEDACTORSREQUEST,
    output_type=_CLIENTLISTNAMEDACTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RAYLETDRIVER)

DESCRIPTOR.services_by_name['RayletDriver'] = _RAYLETDRIVER


_RAYLETDATASTREAMER = _descriptor.ServiceDescriptor(
  name='RayletDataStreamer',
  full_name='ray.rpc.RayletDataStreamer',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6525,
  serialized_end=6608,
  methods=[
  _descriptor.MethodDescriptor(
    name='Datapath',
    full_name='ray.rpc.RayletDataStreamer.Datapath',
    index=0,
    containing_service=None,
    input_type=_DATAREQUEST,
    output_type=_DATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RAYLETDATASTREAMER)

DESCRIPTOR.services_by_name['RayletDataStreamer'] = _RAYLETDATASTREAMER


_RAYLETLOGSTREAMER = _descriptor.ServiceDescriptor(
  name='RayletLogStreamer',
  full_name='ray.rpc.RayletLogStreamer',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6610,
  serialized_end=6695,
  methods=[
  _descriptor.MethodDescriptor(
    name='Logstream',
    full_name='ray.rpc.RayletLogStreamer.Logstream',
    index=0,
    containing_service=None,
    input_type=_LOGSETTINGSREQUEST,
    output_type=_LOGDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RAYLETLOGSTREAMER)

DESCRIPTOR.services_by_name['RayletLogStreamer'] = _RAYLETLOGSTREAMER

# @@protoc_insertion_point(module_scope)
